package shopper;

import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.Image;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.util.ArrayList;
import java.util.List;

import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPasswordField;
import javax.swing.JTextField;

public class Shopper extends JFrame {
	private JMenuBar bar;
	private LoginListener listener;
	private JMenu startMenu;
    private JMenuItem loginItem, logoutItem;
    private JLabel welcome;
    private boolean loggedIn, loggedOut;
    private List<JLabel> prodForSale;
    
	public Shopper() {
		super("CSC207 Shopping App");
		setContentPane(new JLabel(new ImageIcon("Products\\bg.jpg")));
		setLayout(new FlowLayout());
		
		welcome = new JLabel();
		welcome.setFont(new Font ("Sanserif", Font.ITALIC, 10));
		welcome.setEnabled(false);
	    loggedIn = false;
	    loggedOut = true;
		prodForSale = new ArrayList<>();
		addProducts();
		
		bar = new JMenuBar();
		setJMenuBar(bar);
		startMenu = new JMenu("Start");
		bar.add(startMenu);
		
		loginItem = new JMenuItem("Log In");
		loginItem.setMnemonic('I');
		startMenu.add(loginItem);
		listener = new LoginListener();
		loginItem.addActionListener(listener);

		logoutItem = new JMenuItem("Log Out");
		logoutItem.setMnemonic(KeyEvent.VK_T);
		logoutItem.setEnabled(false);
		startMenu.add(logoutItem);

	}
	
	public boolean hasLoggedOut() {
		return loggedOut;
	}

	private class LoginListener implements ActionListener {

		@Override
		public void actionPerformed(ActionEvent arg0) {
			if(isAuthenticated()) {
				loginItem.setEnabled(false);
				logoutItem.setEnabled(true);
				loggedIn = true;
				loggedOut = false;
				bar.add(add(Box.createHorizontalGlue()));
				bar.add(welcome);
				for(JLabel l : prodForSale)
					l.setToolTipText("Add to shopping cart!");
				revalidate();
			}
		}

	}

	private boolean isAuthenticated() {
		JTextField username = new JTextField();
		JTextField password = new JPasswordField();
		Object[] message = {
		    "Username:", username,
		    "Password:", password
		};
        boolean result = false;
		int option = JOptionPane.showConfirmDialog(null, message, "Login", JOptionPane.OK_CANCEL_OPTION);
		if (option == JOptionPane.OK_OPTION) {
			User user = new User(username.getText(), new String(((JPasswordField) password).getPassword()));
		    UserManager m = new UserManager();
		    result = m.validate(user);
		    if(result)
		    	welcome.setText("Welcome, " + username.getText() + "!  ");
		} else {
		    result= false;
		}
		return result;
	}
	
	private void addProducts() {
		ProductManager pm = new ProductManager();
		List<Product> products = pm.getProducts();
        JLabel prod;
		for(Product p : products) {
			ImageIcon prodImage = new ImageIcon("Products\\"+p.getImage());
			prod = new JLabel();
			prod.setIcon(prodImage);
			prod.setText(p.toString());
			prod.setHorizontalTextPosition(JLabel.CENTER);
			prod.setVerticalTextPosition(JLabel.BOTTOM);
			prod.setToolTipText("Login to buy products!");
			add(prod);
			prodForSale.add(prod);
		}
	}
}
